@@ -1,5 +1,3 @@
-from python_framework.api.resource.swaggerui import *
-
 from python_framework.api.src.domain import HttpStatus
 
 from python_framework.api.src.annotation import MethodWrapper
@@ -21,4 +19,6 @@ from python_framework.api.src.service.openapi import OpenApiDocumentationFile
 from python_framework.api.src.service.flask import FlaskManager
 from python_framework.api.src.service.flask import ResourceManager
 
+from python_framework.api.src.annotation.MethodWrapper import *
+from python_framework.api.src.annotation.EnumAnnotation import *
 from python_framework.api.src.service.flask.FlaskManager import *
